package Bencher::ScenarioR::LogGer::Overhead;

our $VERSION = 0.012; # VERSION

our $results = [
  [
    200,
    "OK",
    [
      {
        code_overhead_time => 124,
        errors => 0.00023,
        participant => "use Log::Dispatchouli;",
        proc_private_dirty_size => 568,
        proc_rss_size => 4,
        proc_size => 20,
        samples => 20,
        time => 130,
        vs_slowest => 1,
      },
      {
        code_overhead_time => 88,
        errors => 0.00017,
        participant => "use Log::Contextual qw(:log);",
        proc_private_dirty_size => 572,
        proc_rss_size => 4,
        proc_size => 20,
        samples => 20,
        time => 94,
        vs_slowest => 1.3,
      },
      {
        code_overhead_time => 39,
        errors => 0.00013,
        participant => "use Log::Log4perl;",
        proc_private_dirty_size => 568,
        proc_rss_size => 3.9,
        proc_size => 20,
        samples => 20,
        time => 45,
        vs_slowest => 2.8,
      },
      {
        code_overhead_time => 21,
        errors => 7.9e-05,
        participant => "use Log::ger::App; use Log::ger;",
        proc_private_dirty_size => 572,
        proc_rss_size => 3.9,
        proc_size => 20,
        samples => 20,
        time => 27,
        vs_slowest => 4.6,
      },
      {
        code_overhead_time => 19,
        errors => 3.6e-05,
        participant => "use Log::Log4perl::Tiny;",
        proc_private_dirty_size => 572,
        proc_rss_size => 4,
        proc_size => 20,
        samples => 20,
        time => 25,
        vs_slowest => 5.1,
      },
      {
        code_overhead_time => 13,
        errors => 4.3e-05,
        participant => "use Log::ger::App;",
        proc_private_dirty_size => 572,
        proc_rss_size => 3.9,
        proc_size => 20,
        samples => 21,
        time => 19,
        vs_slowest => 6.7,
      },
      {
        code_overhead_time => 12,
        errors => 6.1e-05,
        participant => "use Log::ger::Like::Log4perl;",
        proc_private_dirty_size => 572,
        proc_rss_size => 4,
        proc_size => 20,
        samples => 20,
        time => 18,
        vs_slowest => 6.9,
      },
      {
        code_overhead_time => 12,
        errors => 7.3e-05,
        participant => "use Log::Any q(\$log);",
        proc_private_dirty_size => 572,
        proc_rss_size => 4,
        proc_size => 20,
        samples => 22,
        time => 18,
        vs_slowest => 7.1,
      },
      {
        code_overhead_time => 11,
        errors => 6.4e-05,
        participant => "use Log::Any;",
        proc_private_dirty_size => 572,
        proc_rss_size => 4,
        proc_size => 20,
        samples => 20,
        time => 17,
        vs_slowest => 7.6,
      },
      {
        code_overhead_time => 7,
        errors => 3.9e-05,
        participant => "use Log::ger::Output::Screen;",
        proc_private_dirty_size => 568,
        proc_rss_size => 4,
        proc_size => 20,
        samples => 20,
        time => 13,
        vs_slowest => 9.5,
      },
      {
        code_overhead_time => 4,
        errors => 2e-05,
        participant => "use Log::ger::Output::Composite;",
        proc_private_dirty_size => 572,
        proc_rss_size => 3.9,
        proc_size => 20,
        samples => 20,
        time => 10,
        vs_slowest => 13,
      },
      {
        code_overhead_time => 3.9,
        errors => 2.5e-05,
        participant => "use Log::ger::Plugin::OptAway; use Log::ger;",
        proc_private_dirty_size => 572,
        proc_rss_size => 4,
        proc_size => 20,
        samples => 20,
        time => 9.9,
        vs_slowest => 13,
      },
      {
        code_overhead_time => 1.4,
        errors => 3e-05,
        participant => "use Log::ger::Like::LogAny;",
        proc_private_dirty_size => 568,
        proc_rss_size => 3.9,
        proc_size => 20,
        samples => 20,
        time => 7.4,
        vs_slowest => 17,
      },
      {
        code_overhead_time => 1,
        errors => 7.2e-05,
        participant => "use Log::ger; Log::ger->get_logger;",
        proc_private_dirty_size => 572,
        proc_rss_size => 4,
        proc_size => 20,
        samples => 20,
        time => 7,
        vs_slowest => 20,
      },
      {
        code_overhead_time => 1,
        errors => 7.5e-05,
        participant => "use Log::ger;",
        proc_private_dirty_size => 572,
        proc_rss_size => 4,
        proc_size => 20,
        samples => 20,
        time => 7,
        vs_slowest => 20,
      },
      {
        code_overhead_time => 1,
        errors => 1.7e-05,
        participant => "use Log::ger ();",
        proc_private_dirty_size => 568,
        proc_rss_size => 4,
        proc_size => 20,
        samples => 20,
        time => 7,
        vs_slowest => 18,
      },
      {
        code_overhead_time => 0,
        errors => 6.5e-05,
        participant => "perl -e1 (baseline)",
        proc_private_dirty_size => 568,
        proc_rss_size => 4,
        proc_size => 20,
        samples => 20,
        time => 6,
        vs_slowest => 20,
      },
    ],
    {
      "func.bencher_args"              => {
                                            action => "bench",
                                            note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                            scenario_module => "LogGer::Overhead",
                                          },
      "func.bencher_version"           => undef,
      "func.code_startup"              => 1,
      "func.cpu_info"                  => [
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "lahf_lm",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "xsaveopt",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 42,
                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 0,
                                              speed                        => 3159.457,
                                              stepping                     => 7,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "lahf_lm",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "xsaveopt",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 42,
                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 1,
                                              speed                        => 3223.878,
                                              stepping                     => 7,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "lahf_lm",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "xsaveopt",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 42,
                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 2,
                                              speed                        => "3205.230",
                                              stepping                     => 7,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "lahf_lm",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "xsaveopt",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 42,
                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 3,
                                              speed                        => 3212.375,
                                              stepping                     => 7,
                                            },
                                          ],
      "func.elapsed_time"              => 11.7200911045074,
      "func.module_startup"            => undef,
      "func.module_versions"           => {
                                            "__PACKAGE__"                         => "1.040",
                                            "Bencher::Scenario::LogGer::Overhead" => undef,
                                            "Benchmark::Dumb"                     => 0.111,
                                            "Devel::Platform::Info"               => 0.16,
                                            "Log::Any"                            => 1.049,
                                            "Log::Contextual"                     => 0.007001,
                                            "Log::Dispatchouli"                   => 2.015,
                                            "Log::ger"                            => 0.023,
                                            "Log::ger::App"                       => 0.003,
                                            "Log::ger::Layout::Pattern"           => 0.001,
                                            "Log::ger::Output"                    => 0.023,
                                            "Log::Log4perl"                       => 1.49,
                                            "Log::Log4perl::Tiny"                 => "1.4.0",
                                            "perl"                                => "v5.26.0",
                                            "Sys::Info"                           => 0.78,
                                          },
      "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 17]],
      "func.platform_info"             => {
                                            archname => "x86_64",
                                            codename => "jessie",
                                            is32bit  => 0,
                                            is64bit  => 1,
                                            kernel   => "linux-3.16.0-4-amd64",
                                            kname    => "Linux",
                                            kvers    => "3.16.0-4-amd64",
                                            osflag   => "linux",
                                            oslabel  => "Debian",
                                            osname   => "GNU/Linux",
                                            osvers   => "8.0",
                                            source   => {
                                                          "cat /etc/.issue" => "",
                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u2 (2016-10-19) x86_64 GNU/Linux",
                                                          "uname -m"        => "x86_64",
                                                          "uname -o"        => "GNU/Linux",
                                                          "uname -r"        => "3.16.0-4-amd64",
                                                          "uname -s"        => "Linux",
                                                        },
                                          },
      "func.precision"                 => 0,
      "func.scenario_module"           => "Bencher::Scenario::LogGer::Overhead",
      "func.scenario_module_md5sum"    => "0edc3d4a26f5e2516bdf1ad69c8c206d",
      "func.scenario_module_mtime"     => 1501851050,
      "func.scenario_module_sha1sum"   => "1865868844b4870a6c50857d2865074b6a056d14",
      "func.scenario_module_sha256sum" => "8470af634e0518da7fd37e1beecf5507d1b5188dffe51727d748505336531ee0",
      "func.time_end"                  => 1501853223.58396,
      "func.time_factor"               => 1000,
      "func.time_start"                => 1501853211.86386,
      "table.field_aligns"             => [
                                            "left",
                                            "left",
                                            "left",
                                            "left",
                                            "number",
                                            "number",
                                            "number",
                                            "number",
                                            "number",
                                          ],
      "table.field_units"              => [undef, "kB", "MB", "MB", "ms", "ms"],
      "table.fields"                   => [
                                            "participant",
                                            "proc_private_dirty_size",
                                            "proc_rss_size",
                                            "proc_size",
                                            "time",
                                            "code_overhead_time",
                                            "vs_slowest",
                                            "errors",
                                            "samples",
                                          ],
    },
  ],
];

1;
# ABSTRACT: Measure startup overhead of various codes

=head1 DESCRIPTION

This module is automatically generated by Pod::Weaver::Plugin::Bencher::Scenario during distribution build.

A Bencher::ScenarioR::* module contains the raw result of sample benchmark and might be useful for some stuffs later.

